//
//  TrafficTableViewCell.m
//  TestTravelController
//
//  Created by Apple on 17/3/21.
//  Copyright © 2017年 手握日月摘星辰，世间无我这般人. All rights reserved.
//

#import "TrafficTableViewCell.h"
#import "ShowTrafficDetailView.h"

@interface TrafficTableViewCell ()<HiddenTraficDetailViewDelegate>

#pragma mark－－－－－－－－－－视图部分

/**trafficName**/
@property(strong,nonatomic) UILabel *trafficNameLabel;

/**trafficDown**/
@property(strong,nonatomic) UIImageView *downImageView;

/**trafficWayImage**/
@property(strong,nonatomic) UIImageView *trafficWayImageView;

/**trafficDisORNum**/
@property(strong,nonatomic) UILabel *trafficDisNumLabel;

/**trafficstations**/
@property(strong,nonatomic) UIButton  *stationBtn;

@property(strong,nonatomic) ShowTrafficDetailView *detailTrafficView;


#pragma mark－－－－－－－－－－数据部分
@property(strong,nonatomic) TrafficModel *currentModel;



@end


@implementation TrafficTableViewCell

-(instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    if (self=[super initWithStyle:style reuseIdentifier:reuseIdentifier]) {
        
        self.backgroundColor=[UIColor clearColor];
        self.selectionStyle=UITableViewCellSelectionStyleNone;
        //创建视图
        [self createMainView];
    }
    return self;
}



#pragma mark－－－－－－－－－－－－－－－创建视图－－－－－－－－－－
-(void)createMainView
{
    //名称
    self.trafficNameLabel=[[UILabel alloc]initWithFrame:CGRectMake(0,0,100,40)];
    self.trafficNameLabel.font=[UIFont systemFontOfSize:13];
    self.trafficNameLabel.textColor=[UIColor lightGrayColor];
    [self.contentView addSubview:self.trafficNameLabel];
    
    //站数
    self.stationBtn=[UIButton buttonWithType:UIButtonTypeRoundedRect];
    self.stationBtn.frame=CGRectMake(100,10,50,20);
    self.stationBtn.hidden=YES;
    [self.stationBtn setTitleColor:[UIColor lightGrayColor] forState:UIControlStateNormal];
    self.stationBtn.titleLabel.textAlignment=NSTextAlignmentLeft;
    self.stationBtn.titleLabel.font=[UIFont systemFontOfSize:11];
    [self.stationBtn addTarget:self action:@selector(showTrafficDetail) forControlEvents:UIControlEventTouchUpInside];
    [self.contentView addSubview:self.stationBtn];
    
    
    //向下箭头
    self.downImageView=[[UIImageView alloc]initWithFrame:CGRectMake(150,15,10,10)];
    self.downImageView.image=[UIImage imageNamed:@"icon-双向箭头下@2x.png"];
    self.downImageView.contentMode=UIViewContentModeScaleAspectFit;
    [self.contentView addSubview:self.downImageView];
    
    //交通方式标志
    self.trafficWayImageView=[[UIImageView alloc]initWithFrame:CGRectMake(160,10,20,20)];
    self.trafficWayImageView.contentMode=UIViewContentModeScaleAspectFit;
    [self.contentView addSubview:self.trafficWayImageView];
    
    //距离或者车号
    self.trafficDisNumLabel=[[UILabel alloc]initWithFrame:CGRectMake(180,0,UIScreen_Width-180,40)];
    self.trafficDisNumLabel.textColor=[UIColor lightGrayColor];
    self.trafficDisNumLabel.font=[UIFont systemFontOfSize:13];
    [self.contentView addSubview:self.trafficDisNumLabel];
}

#pragma mark－－－－－－－－－－－－－－－请求数据－－－－－－－－－－
-(void)requestTraffic:(TrafficModel *)trafficModel
{
    self.currentModel=trafficModel;
    self.trafficNameLabel.text=trafficModel.trafficName;
    
    CGSize textSize=[self calculationTextLength:self.trafficNameLabel.text textFont:13];
    self.trafficNameLabel.frame=CGRectMake(0,0,textSize.width,40);
    self.stationBtn.frame=CGRectMake(textSize.width-10,10,50,20);
    
    self.trafficDisNumLabel.text=trafficModel.trafficDisNum;
    NSInteger trafficType=[trafficModel.trafficType integerValue];
    if (trafficType==1) {
        self.trafficWayImageView.image=[UIImage imageNamed:@"icon-步行@2x.png"];
        self.stationBtn.hidden=YES;
    }else if (trafficType==2){
        self.trafficWayImageView.image=[UIImage imageNamed:@"icon-bus@2x.png"];
        if (trafficModel.trafficViaStops.count>0) {
            self.stationBtn.hidden=NO;
            [self.stationBtn setTitle:[NSString stringWithFormat:@"<%d>站",trafficModel.trafficViaStops.count] forState:UIControlStateNormal];
        }
    }else if (trafficType==3){
        self.trafficWayImageView.image=[UIImage imageNamed:@"icon-地铁@2x.png"];
        if (trafficModel.trafficViaStops.count>0) {
            self.stationBtn.hidden=NO;
            [self.stationBtn setTitle:[NSString stringWithFormat:@"%d站",trafficModel.trafficViaStops.count] forState:UIControlStateNormal];
        }
    }else if (trafficType==5){
        self.trafficWayImageView.hidden=YES;
        self.downImageView.hidden=YES;
    }
}
#pragma mark－－－－－－－－－－－－－－－用户交互－－－－－－－－－－
//显示详细交通数据
-(void)showTrafficDetail
{
    UITableViewController *tempController=(UITableViewController*)self.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder;
    tempController.navigationController.navigationBar.hidden=YES;
    self.detailTrafficView=[[ShowTrafficDetailView alloc]initWithFrame:CGRectMake(0,0,UIScreen_Width,UIScreen_Height)];
    self.detailTrafficView.delegate=self;
    [self.detailTrafficView requestTrafficInfo:self.currentModel.trafficViaStops];
    [self.window addSubview:self.detailTrafficView];
}

//点击隐藏按钮
-(void)hiddenView
{
    [self.detailTrafficView removeFromSuperview];
    UITableViewController *tempController=(UITableViewController*)self.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder.nextResponder;
    tempController.navigationController.navigationBar.hidden=NO;
}


//计算文字的长度
-(CGSize)calculationTextLength:(NSString*)text textFont:(CGFloat)font
{
    NSDictionary *titleDic=@{NSFontAttributeName:[UIFont systemFontOfSize:font]};
    CGSize title=CGSizeMake(UIScreen_Width,10000);
    CGSize textSize=[text boundingRectWithSize:title options:NSStringDrawingTruncatesLastVisibleLine | NSStringDrawingUsesLineFragmentOrigin | NSStringDrawingUsesFontLeading attributes:titleDic context:nil].size;
    return textSize;
}





- (void)awakeFromNib {
    [super awakeFromNib];
    // Initialization code
}

- (void)setSelected:(BOOL)selected animated:(BOOL)animated {
    [super setSelected:selected animated:animated];

    // Configure the view for the selected state
}

@end
